# to avoid import complications.
# from blue_objects.env import ABCLI_PUBLIC_PREFIX
ABCLI_PUBLIC_PREFIX = "https://kamangir-public.s3.ca-central-1.amazonaws.com"

NAME = "vancouver_watching"

ICON = "🌈"

DESCRIPTION = f"{ICON} Vancouver Watching with AI."

VERSION = "3.512.1"

REPO_NAME = "vancouver-watching"

MARQUEE = f"{ABCLI_PUBLIC_PREFIX}/test_vancouver_watching_ingest/animation.gif"

ALIAS = "vanwatch"


def fullname() -> str:
    return f"{NAME}-{VERSION}"
